neural-network-from-scratch
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

``` python
neural_network_from_scratch.core??
```

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install neural_network_from_scratch
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
#minus_one()
```

    NameError: name 'minus_one' is not defined

``` python
#foo()
```

``` python
#foo?
```

``` python
#add_one(2)
```

    NameError: name 'add_one' is not defined

``` python
#foo(1)
```

    NameError: name 'hoo' is not defined

``` python
1+1
```

    2

``` python
#hoo??
```

    Object `hoo` not found.

``` python
#hoo(1)
```

    NameError: name 'hoo' is not defined

``` python
#activation??
```

    Object `activation` not found.

``` python
#activation(10)
```

    NameError: name 'activation' is not defined
